class ComicsController < ApplicationController
  before_filter :authenticate_user!, :only => [:top, :index, :show, :play, :create, :update, :destroy]
  before_filter :authenticate_admin!, :only => [:list, :browse]

  private
  
  def treat_param comic
    comic.author_id = @author.id
  end
  
  public
  
  def top
    @new_comics = Comic.find(:all, 
      :include => :author, :conditions => ['visible = 1'], :order => 'updated_at desc', :limit => 5
    )
    @new_pictures = OriginalPicture.find(:all, 
      :include => [:artist, :license, :resource_picture], :order => 'updated_at', :limit => 5
    )

    respond_to do |format|
      format.html # index.html.erb
    end
  end
  
  # GET /comics
  # GET /comics.json
  def index
    @comics = Comic.find(:all, 
      :include => :author, :conditions => ['visible = 1'], :order => 'updated_at desc', :limit => 20
    )

    respond_to do |format|
      format.html # index.html.erb
      format.json { render json: @comics }
    end
  end

  # GET /comics/1
  # GET /comics/1.json
  def show
    @comic = Comic.find(params[:id])

    respond_to do |format|
#      format.html # show.html.erb
      format.json { render json: @comic }
    end
  end

  def play
    @comic = Comic.find(params[:id], include: [:author, {:panels => [:panel_pictures => :resource_picture, :balloons => :speaches]}], order: 'panels.t')

    respond_to do |format|
      format.html # index.html.erb
      format.json {
        render :json => @comic.to_json(
          :include => [:author, {
            :panels => {:include => {
              :panel_pictures => {:include => :resource_picture}, 
              :balloons => {:include => :speaches}
            }}
          }]
        )
      }
      format.jsonp {
        render :json => "callback(" + @comic.to_json(
          :include => {
            :panels => {:include => {
              :panel_pictures => {:include => :resource_picture}, 
              :balloons => {:include => :speaches}
            }}
          }
        ) + ");"
      }
    end
  end
  
  def list
    @comics = Comic.all

    respond_to do |format|
      format.html { render layout: 'system' }# index.html.erb
      format.json { render json: @comics }
    end
  end

  def browse
    @comic = Comic.find(params[:id])

    respond_to do |format|
      format.html { render layout: 'system' } # show.html.erb
      format.json { render json: @comic }
    end
  end
  
  # GET /comics/new
  # GET /comics/new.json
  def new
    @comic = Comic.new
    @comic.supply_default
    respond_to do |format|
      format.html # new.html.erb
      format.json { render json: @comic }
    end
  end

  # GET /comics/1/edit
  def edit
    @comic = Comic.find(params[:id])
  end

  # POST /comics
  # POST /comics.json
  def create
    params[:comic].merge! author_id: @author.id
    @comic = Comic.new params[:comic]
    @comic.supply_default 

    respond_to do |format|
      if @comic.save
        format.html { redirect_to @comic, notice: 'Comic was successfully created.' }
        format.json { render json: @comic, status: :created, location: @comic }
      else
        format.html { render action: "new" }
        format.json { render json: @comic.errors, status: :unprocessable_entity }
      end
    end
  end

  # PUT /comics/1
  # PUT /comics/1.json
  def update
    params[:comic].merge! author_id: @author.id
    @comic = Comic.find(params[:id])
    respond_to do |format|
      if @comic.own? @author
        if @comic.update_attributes(params[:comic])
          format.html { redirect_to @comic, notice: 'Comic was successfully updated.' }
          format.json { head :ok }
        else
          format.html { render action: "edit" }
          format.json { render json: @comic.errors, status: :unprocessable_entity }
        end
      else
        format.html { render action: "edit" }
        format.json { render json: @comic.errors, status: :unprocessable_entity }
      end
    end
  end

  # DELETE /comics/1
  # DELETE /comics/1.json
  def destroy
    @comic = Comic.find(params[:id])
    if @comic.own? @author
      @comic.destroy
      respond_to do |format|
        format.html { redirect_to comics_url }
        format.json { head :ok }
      end
    else
      format.html { render action: "edit" }
      format.json { render json: @comic.errors, status: :unprocessable_entity }
    end
  end
end
