class Comic < ActiveRecord::Base
  has_many :panels, :dependent => :destroy
  belongs_to :author
  
  class NotZeroValidator < ActiveModel::EachValidator
    def validate_each(record, attribute, value)
      record.errors[attribute] << (options[:message] || "is zero") if value == 0
    end
  end

  validates :title, :presence => true, :length => {:maximum => 100}
  validates :width, :presence => true, :numericality => true, :not_zero => true
  validates :height, :presence => true, :numericality => true, :not_zero => true
  validates :visible, :presence => true, :numericality => true, :inclusion => {:in => 0...4}
  validates :editable, :presence => true, :numericality => true, :inclusion => {:in => 0...4}
  
  before_save do |r|
    r.supply_default
  end
  
  def supply_default
    self.visible = 0 if self.visible.blank?
    self.editable= 0 if self.editable.blank?
  end
  
  def own? author
    return false unless author
    self.author_id == author.id
  end
  
  def disp_editable
    editable == 1 ? 'O' : 'X'
  end
  
  def disp_visible
    visible == 1 ? 'O' : 'X'
  end
  
end
